@@ -215,18 +215,18 @@ class Foreperson:
             else:
                 raise ValueError("No beam width given in setup of {}.".format(yaml_file))
             if 'theta_axis' in recipe['setup'].keys():
-                self.experiment.measurement.theta_axis_name = recipe['setup']['theta_axis']
+                self.data_source.experiment.measurement.theta_axis_name = recipe['setup']['theta_axis']
             if 'q axis' in recipe['setup'].keys():
-                self.experiment.measurement.q_axis_name = recipe['setup']['q axis']
+                self.data_source.experiment.measurement.q_axis_name = recipe['setup']['q axis']
             if 'transpose' in recipe['setup'].keys():
-                self.experiment.measurement.transpose = recipe['setup']['transpose']
-                if self.experiment.measurement.transpose:
-                    self.experiment.measurement.qz_dimension = 0
-                    self.experiment.measurement.qxy_dimension = 1
+                self.data_source.experiment.measurement.transpose = recipe['setup']['transpose']
+                if self.data_source.experiment.measurement.transpose:
+                    self.data_source.experiment.measurement.qz_dimension = 0
+                    self.data_source.experiment.measurement.qxy_dimension = 1
             if 'pixel_max' in recipe['setup'].keys():
-                self.experiment.measurement.pixel_max = recipe['setup']['pixel_max']
+                self.data_source.experiment.measurement.pixel_max = recipe['setup']['pixel_max']
             if 'hot_pixel_max' in recipe['setup'].keys():
-                self.experiment.measurement.hot_pixel_max = recipe['setup']['hot_pixel_max']
+                self.data_source.experiment.measurement.hot_pixel_max = recipe['setup']['hot_pixel_max']
         else:
             raise ValueError("No setup given in {}.".format(yaml_file))
         if 'output_columns' in keys:
